aboutsummaryrefslogtreecommitdiffstats
path: root/examples/itemviews/addressbook/addressbook.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/itemviews/addressbook/addressbook.py')
-rwxr-xr-xexamples/itemviews/addressbook/addressbook.py92
1 files changed, 44 insertions, 48 deletions
diff --git a/examples/itemviews/addressbook/addressbook.py b/examples/itemviews/addressbook/addressbook.py
index a3fec1d..4e68d27 100755
--- a/examples/itemviews/addressbook/addressbook.py
+++ b/examples/itemviews/addressbook/addressbook.py
@@ -1,48 +1,47 @@
#!/usr/bin/python
-"""**************************************************************************
-**
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
-**
-** This file is part of the examples of the Qt Toolkit.
-**
-** You may use this file under the terms of the BSD license as follows:
-**
-** "Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
-** * Redistributions of source code must retain the above copyright
-** notice, this list of conditions and the following disclaimer.
-** * Redistributions in binary form must reproduce the above copyright
-** notice, this list of conditions and the following disclaimer in
-** the documentation and/or other materials provided with the
-** distribution.
-** * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
-** the names of its contributors may be used to endorse or promote
-** products derived from this software without specific prior written
-** permission.
-**
-** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
-**
-*****************************************************************************
-** February 2011
-** - addressbook example ported to PySide by Arun Srinivasan
-** <rulfzid@gmail.com>
-**************************************************************************"""
-
-from PySide.QtGui import (QMainWindow, QAction, QFileDialog, QApplication)
+#############################################################################
+##
+## Copyright (C) 2011 Arun Srinivasan <rulfzid@gmail.com>
+## Copyright (C) 2016 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the PySide examples of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:BSD$
+## You may use this file under the terms of the BSD license as follows:
+##
+## "Redistribution and use in source and binary forms, with or without
+## modification, are permitted provided that the following conditions are
+## met:
+## * Redistributions of source code must retain the above copyright
+## notice, this list of conditions and the following disclaimer.
+## * Redistributions in binary form must reproduce the above copyright
+## notice, this list of conditions and the following disclaimer in
+## the documentation and/or other materials provided with the
+## distribution.
+## * Neither the name of The Qt Company Ltd nor the names of its
+## contributors may be used to endorse or promote products derived
+## from this software without specific prior written permission.
+##
+##
+## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+## A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+## OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+## DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+## THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+## OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+from PySide2.QtWidgets import (QMainWindow, QAction, QFileDialog, QApplication)
from addresswidget import AddressWidget
@@ -94,13 +93,10 @@ class MainWindow(QMainWindow):
# Quick gotcha:
#
# QFiledialog.getOpenFilename and QFileDialog.get.SaveFileName don't
# behave in PySide as they do in QT, where they return a QString
# containing the filename.
#
# In PySide (and, I believe, PyQT), these functions return a tuple:
# (filename, filter)
#
# http://www.pyside.org/docs/pyside/PySide/QtGui/QFileDialog.html
def openFile(self):
filename, _ = QFileDialog.getOpenFileName(self)
@@ -94,13 +93,10 @@ class MainWindow(QMainWindow):
#
# QFiledialog.getOpenFilename and QFileDialog.get.SaveFileName don't
- # behave in PySide as they do in QT, where they return a QString
+ # behave in PySide2 as they do in Qt, where they return a QString
# containing the filename.
#
@@ -94,13 +93,10 @@ class MainWindow(QMainWindow):
# containing the filename.
#
- # In PySide (and, I believe, PyQT), these functions return a tuple:
- # (filename, filter)
- #
- # http://www.pyside.org/docs/pyside/PySide/QtGui/QFileDialog.html
+ # In PySide2, these functions return a tuple: (filename, filter)
def openFile(self):
filename, _ = QFileDialog.getOpenFileName(self)